/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIHttpProtocolHandler.idl
 */

#ifndef __gen_nsIHttpProtocolHandler_h__
#define __gen_nsIHttpProtocolHandler_h__


#ifndef __gen_nsIProtocolHandler_h__
#include "nsIProtocolHandler.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIHttpProtocolHandler */
#define NS_IHTTPPROTOCOLHANDLER_IID_STR "122c91c0-2485-40ba-89c9-b895934921bc"

#define NS_IHTTPPROTOCOLHANDLER_IID \
  {0x122c91c0, 0x2485, 0x40ba, \
    { 0x89, 0xc9, 0xb8, 0x95, 0x93, 0x49, 0x21, 0xbc }}

class NS_NO_VTABLE nsIHttpProtocolHandler : public nsIProtocolHandler {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IHTTPPROTOCOLHANDLER_IID)

  /**
     * Constructs a new http proxy channel.
     *
     * @param uri       - the desired request-URI (eg. ftp://ftp.mozilla.org/)
     * @param proxyHost - the proxy hostname
     * @param proxyPort - the proxy port
     * @param proxyType - the proxy type (usually "http" or "socks")
     */
  /* nsIChannel newProxyChannel (in nsIURI uri, in string proxyHost, in long proxyPort, in string proxyType); */
  NS_IMETHOD NewProxyChannel(nsIURI *uri, const char *proxyHost, PRInt32 proxyPort, const char *proxyType, nsIChannel **_retval) = 0;

  /**
     * Get the HTTP advertised user agent string.
     */
  /* readonly attribute string userAgent; */
  NS_IMETHOD GetUserAgent(char * *aUserAgent) = 0;

  /**
     * Get the application name.
	 *
     * @return The name of this application (eg. "Mozilla").
     */
  /* readonly attribute string appName; */
  NS_IMETHOD GetAppName(char * *aAppName) = 0;

  /**
     * Get the application version string.
     *
     * @return The complete version (major and minor) string. (eg. "5.0")
     */
  /* readonly attribute string appVersion; */
  NS_IMETHOD GetAppVersion(char * *aAppVersion) = 0;

  /**
     * @return The vendor name.
     */
  /* attribute string vendor; */
  NS_IMETHOD GetVendor(char * *aVendor) = 0;
  NS_IMETHOD SetVendor(const char * aVendor) = 0;

  /**
     * @return The vendor sub string.
     */
  /* attribute string vendorSub; */
  NS_IMETHOD GetVendorSub(char * *aVendorSub) = 0;
  NS_IMETHOD SetVendorSub(const char * aVendorSub) = 0;

  /**
     * @return The vendor comment.
     */
  /* attribute string vendorComment; */
  NS_IMETHOD GetVendorComment(char * *aVendorComment) = 0;
  NS_IMETHOD SetVendorComment(const char * aVendorComment) = 0;

  /**
     * @return The product name.
     */
  /* attribute string product; */
  NS_IMETHOD GetProduct(char * *aProduct) = 0;
  NS_IMETHOD SetProduct(const char * aProduct) = 0;

  /**
     * @return A product sub string.
     */
  /* attribute string productSub; */
  NS_IMETHOD GetProductSub(char * *aProductSub) = 0;
  NS_IMETHOD SetProductSub(const char * aProductSub) = 0;

  /**
     * @return A product comment.
     */
  /* attribute string productComment; */
  NS_IMETHOD GetProductComment(char * *aProductComment) = 0;
  NS_IMETHOD SetProductComment(const char * aProductComment) = 0;

  /**
     * Get the current platform.
     *
     * @return The platform this application is running on
     *		   (eg. "Windows", "Macintosh", "X11")
     */
  /* readonly attribute string platform; */
  NS_IMETHOD GetPlatform(char * *aPlatform) = 0;

  /**
     * Get the current oscpu.
     *
     * @return The oscpu this application is running on
     */
  /* readonly attribute string oscpu; */
  NS_IMETHOD GetOscpu(char * *aOscpu) = 0;

  /**
     * Get the translation of the application. The value for language
     * is usually a 2-letter code such as "en" and occasionally a 
     * five-character code to indicate a language subtype, such as "zh_CN". 
     */
  /* attribute string language; */
  NS_IMETHOD GetLanguage(char * *aLanguage) = 0;
  NS_IMETHOD SetLanguage(const char * aLanguage) = 0;

  /**
     * Get/Set the application comment misc portion.
     */
  /* attribute string misc; */
  NS_IMETHOD GetMisc(char * *aMisc) = 0;
  NS_IMETHOD SetMisc(const char * aMisc) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIHTTPPROTOCOLHANDLER \
  NS_IMETHOD NewProxyChannel(nsIURI *uri, const char *proxyHost, PRInt32 proxyPort, const char *proxyType, nsIChannel **_retval); \
  NS_IMETHOD GetUserAgent(char * *aUserAgent); \
  NS_IMETHOD GetAppName(char * *aAppName); \
  NS_IMETHOD GetAppVersion(char * *aAppVersion); \
  NS_IMETHOD GetVendor(char * *aVendor); \
  NS_IMETHOD SetVendor(const char * aVendor); \
  NS_IMETHOD GetVendorSub(char * *aVendorSub); \
  NS_IMETHOD SetVendorSub(const char * aVendorSub); \
  NS_IMETHOD GetVendorComment(char * *aVendorComment); \
  NS_IMETHOD SetVendorComment(const char * aVendorComment); \
  NS_IMETHOD GetProduct(char * *aProduct); \
  NS_IMETHOD SetProduct(const char * aProduct); \
  NS_IMETHOD GetProductSub(char * *aProductSub); \
  NS_IMETHOD SetProductSub(const char * aProductSub); \
  NS_IMETHOD GetProductComment(char * *aProductComment); \
  NS_IMETHOD SetProductComment(const char * aProductComment); \
  NS_IMETHOD GetPlatform(char * *aPlatform); \
  NS_IMETHOD GetOscpu(char * *aOscpu); \
  NS_IMETHOD GetLanguage(char * *aLanguage); \
  NS_IMETHOD SetLanguage(const char * aLanguage); \
  NS_IMETHOD GetMisc(char * *aMisc); \
  NS_IMETHOD SetMisc(const char * aMisc); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIHTTPPROTOCOLHANDLER(_to) \
  NS_IMETHOD NewProxyChannel(nsIURI *uri, const char *proxyHost, PRInt32 proxyPort, const char *proxyType, nsIChannel **_retval) { return _to ## NewProxyChannel(uri, proxyHost, proxyPort, proxyType, _retval); } \
  NS_IMETHOD GetUserAgent(char * *aUserAgent) { return _to ## GetUserAgent(aUserAgent); } \
  NS_IMETHOD GetAppName(char * *aAppName) { return _to ## GetAppName(aAppName); } \
  NS_IMETHOD GetAppVersion(char * *aAppVersion) { return _to ## GetAppVersion(aAppVersion); } \
  NS_IMETHOD GetVendor(char * *aVendor) { return _to ## GetVendor(aVendor); } \
  NS_IMETHOD SetVendor(const char * aVendor) { return _to ## SetVendor(aVendor); } \
  NS_IMETHOD GetVendorSub(char * *aVendorSub) { return _to ## GetVendorSub(aVendorSub); } \
  NS_IMETHOD SetVendorSub(const char * aVendorSub) { return _to ## SetVendorSub(aVendorSub); } \
  NS_IMETHOD GetVendorComment(char * *aVendorComment) { return _to ## GetVendorComment(aVendorComment); } \
  NS_IMETHOD SetVendorComment(const char * aVendorComment) { return _to ## SetVendorComment(aVendorComment); } \
  NS_IMETHOD GetProduct(char * *aProduct) { return _to ## GetProduct(aProduct); } \
  NS_IMETHOD SetProduct(const char * aProduct) { return _to ## SetProduct(aProduct); } \
  NS_IMETHOD GetProductSub(char * *aProductSub) { return _to ## GetProductSub(aProductSub); } \
  NS_IMETHOD SetProductSub(const char * aProductSub) { return _to ## SetProductSub(aProductSub); } \
  NS_IMETHOD GetProductComment(char * *aProductComment) { return _to ## GetProductComment(aProductComment); } \
  NS_IMETHOD SetProductComment(const char * aProductComment) { return _to ## SetProductComment(aProductComment); } \
  NS_IMETHOD GetPlatform(char * *aPlatform) { return _to ## GetPlatform(aPlatform); } \
  NS_IMETHOD GetOscpu(char * *aOscpu) { return _to ## GetOscpu(aOscpu); } \
  NS_IMETHOD GetLanguage(char * *aLanguage) { return _to ## GetLanguage(aLanguage); } \
  NS_IMETHOD SetLanguage(const char * aLanguage) { return _to ## SetLanguage(aLanguage); } \
  NS_IMETHOD GetMisc(char * *aMisc) { return _to ## GetMisc(aMisc); } \
  NS_IMETHOD SetMisc(const char * aMisc) { return _to ## SetMisc(aMisc); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIHTTPPROTOCOLHANDLER(_to) \
  NS_IMETHOD NewProxyChannel(nsIURI *uri, const char *proxyHost, PRInt32 proxyPort, const char *proxyType, nsIChannel **_retval) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##-> NewProxyChannel(uri, proxyHost, proxyPort, proxyType, _retval); } \
  NS_IMETHOD GetUserAgent(char * *aUserAgent) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetUserAgent(aUserAgent); } \
  NS_IMETHOD GetAppName(char * *aAppName) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetAppName(aAppName); } \
  NS_IMETHOD GetAppVersion(char * *aAppVersion) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetAppVersion(aAppVersion); } \
  NS_IMETHOD GetVendor(char * *aVendor) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetVendor(aVendor); } \
  NS_IMETHOD SetVendor(const char * aVendor) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetVendor(aVendor); } \
  NS_IMETHOD GetVendorSub(char * *aVendorSub) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetVendorSub(aVendorSub); } \
  NS_IMETHOD SetVendorSub(const char * aVendorSub) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetVendorSub(aVendorSub); } \
  NS_IMETHOD GetVendorComment(char * *aVendorComment) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetVendorComment(aVendorComment); } \
  NS_IMETHOD SetVendorComment(const char * aVendorComment) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetVendorComment(aVendorComment); } \
  NS_IMETHOD GetProduct(char * *aProduct) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetProduct(aProduct); } \
  NS_IMETHOD SetProduct(const char * aProduct) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetProduct(aProduct); } \
  NS_IMETHOD GetProductSub(char * *aProductSub) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetProductSub(aProductSub); } \
  NS_IMETHOD SetProductSub(const char * aProductSub) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetProductSub(aProductSub); } \
  NS_IMETHOD GetProductComment(char * *aProductComment) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetProductComment(aProductComment); } \
  NS_IMETHOD SetProductComment(const char * aProductComment) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetProductComment(aProductComment); } \
  NS_IMETHOD GetPlatform(char * *aPlatform) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetPlatform(aPlatform); } \
  NS_IMETHOD GetOscpu(char * *aOscpu) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetOscpu(aOscpu); } \
  NS_IMETHOD GetLanguage(char * *aLanguage) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetLanguage(aLanguage); } \
  NS_IMETHOD SetLanguage(const char * aLanguage) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetLanguage(aLanguage); } \
  NS_IMETHOD GetMisc(char * *aMisc) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->GetMisc(aMisc); } \
  NS_IMETHOD SetMisc(const char * aMisc) { return !_to ## ? NS_ERROR_NULL_POINTER : _to ##->SetMisc(aMisc); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsHttpProtocolHandler : public nsIHttpProtocolHandler
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIHTTPPROTOCOLHANDLER

  nsHttpProtocolHandler();
  virtual ~nsHttpProtocolHandler();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsHttpProtocolHandler, nsIHttpProtocolHandler)

nsHttpProtocolHandler::nsHttpProtocolHandler()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsHttpProtocolHandler::~nsHttpProtocolHandler()
{
  /* destructor code */
}

/* nsIChannel newProxyChannel (in nsIURI uri, in string proxyHost, in long proxyPort, in string proxyType); */
NS_IMETHODIMP nsHttpProtocolHandler::NewProxyChannel(nsIURI *uri, const char *proxyHost, PRInt32 proxyPort, const char *proxyType, nsIChannel **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string userAgent; */
NS_IMETHODIMP nsHttpProtocolHandler::GetUserAgent(char * *aUserAgent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string appName; */
NS_IMETHODIMP nsHttpProtocolHandler::GetAppName(char * *aAppName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string appVersion; */
NS_IMETHODIMP nsHttpProtocolHandler::GetAppVersion(char * *aAppVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string vendor; */
NS_IMETHODIMP nsHttpProtocolHandler::GetVendor(char * *aVendor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetVendor(const char * aVendor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string vendorSub; */
NS_IMETHODIMP nsHttpProtocolHandler::GetVendorSub(char * *aVendorSub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetVendorSub(const char * aVendorSub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string vendorComment; */
NS_IMETHODIMP nsHttpProtocolHandler::GetVendorComment(char * *aVendorComment)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetVendorComment(const char * aVendorComment)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string product; */
NS_IMETHODIMP nsHttpProtocolHandler::GetProduct(char * *aProduct)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetProduct(const char * aProduct)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string productSub; */
NS_IMETHODIMP nsHttpProtocolHandler::GetProductSub(char * *aProductSub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetProductSub(const char * aProductSub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string productComment; */
NS_IMETHODIMP nsHttpProtocolHandler::GetProductComment(char * *aProductComment)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetProductComment(const char * aProductComment)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string platform; */
NS_IMETHODIMP nsHttpProtocolHandler::GetPlatform(char * *aPlatform)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string oscpu; */
NS_IMETHODIMP nsHttpProtocolHandler::GetOscpu(char * *aOscpu)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string language; */
NS_IMETHODIMP nsHttpProtocolHandler::GetLanguage(char * *aLanguage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetLanguage(const char * aLanguage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string misc; */
NS_IMETHODIMP nsHttpProtocolHandler::GetMisc(char * *aMisc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsHttpProtocolHandler::SetMisc(const char * aMisc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

// HTTP protocol handler will do_GetService() on each ContractId that is
// registered under this category when it comes alive.
#define NS_HTTP_STARTUP_CATEGORY "http-startup-category"
// If the resulting service implements nsIObserver, then its Observer
// method will be invoked with the following topic.
#define NS_HTTP_STARTUP_TOPIC (NS_LITERAL_STRING("http-startup").get())

#endif /* __gen_nsIHttpProtocolHandler_h__ */
